<?php
/* ------------------------------------------------------------------------- *
 *  Dynamic styles
/* ------------------------------------------------------------------------- */

/*  Convert hexadecimal to rgb
/* ------------------------------------ */
if ( ! function_exists( 'alx_hex2rgb' ) ) {

	function alx_hex2rgb( $hex, $array=false ) {
		$hex = str_replace("#", "", $hex);

		if ( strlen($hex) == 3 ) {
			$r = hexdec(substr($hex,0,1).substr($hex,0,1));
			$g = hexdec(substr($hex,1,1).substr($hex,1,1));
			$b = hexdec(substr($hex,2,1).substr($hex,2,1));
		} else {
			$r = hexdec(substr($hex,0,2));
			$g = hexdec(substr($hex,2,2));
			$b = hexdec(substr($hex,4,2));
		}

		$rgb = array( $r, $g, $b );
		if ( !$array ) { $rgb = implode(",", $rgb); }
		return $rgb;
	}
	
}	


/*  Google fonts
/* ------------------------------------ */
if ( ! function_exists( 'alx_google_fonts' ) ) {

	function alx_google_fonts () {
		if ( ot_get_option('dynamic-styles') != 'off' ) {
			if ( ot_get_option( 'font' ) == 'higgs-byekan' ) { echo '<link href="'.get_template_directory_uri() .'/rtl/Higgs-BYekan.css" rel="stylesheet" type="text/css">'. "\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-bkoodakbold' ) { echo '<link href="'.get_template_directory_uri() .'/rtl/Higgs-BKoodakBold.css" rel="stylesheet" type="text/css">'. "\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-casablanca' ) { echo '<link href="'.get_template_directory_uri() .'/rtl/Higgs-Casablanca.css" rel="stylesheet" type="text/css">'. "\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-helve23' ) { echo '<link href="'.get_template_directory_uri() .'/rtl/Higgs-Helve23.css" rel="stylesheet" type="text/css">'. "\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-kufi' ) { echo '<link href="'.get_template_directory_uri() .'/rtl/Higgs-Kufi.css" rel="stylesheet" type="text/css">'. "\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-Kufi-bold' ) { echo '<link href="'.get_template_directory_uri() .'/rtl/Higgs-Kufi-Bold.css" rel="stylesheet" type="text/css">'. "\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-naskh' ) { echo '<link href="'.get_template_directory_uri() .'/rtl/Higgs-Naskh.css" rel="stylesheet" type="text/css">'. "\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-naskh-bold' ) { echo '<link href="'.get_template_directory_uri() .'/rtl/Higgs-Naskh-Bold.css" rel="stylesheet" type="text/css">'. "\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-neoSans' ) { echo '<link href="'.get_template_directory_uri() .'/rtl/Higgs-NeoSans.css" rel="stylesheet" type="text/css">'. "\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-sans' ) { echo '<link href="'.get_template_directory_uri() .'/rtl/Higgs-Sans.css" rel="stylesheet" type="text/css">'. "\n"; }
		}
	}	
	
}
add_action( 'wp_head', 'alx_google_fonts', 2 );	


/*  Dynamic css output
/* ------------------------------------ */
if ( ! function_exists( 'alx_dynamic_css' ) ) {

	function alx_dynamic_css() {
		if ( ot_get_option('dynamic-styles') != 'off' ) {
		
			// rgb values
			$color_1 = ot_get_option('color-1');
			$color_1_rgb = alx_hex2rgb($color_1);
			
			// start output
			$styles = '<style type="text/css">'."\n";
			$styles .= '/* Dynamic CSS: For no styles in head, copy and put the css below in your custom.css or child theme\'s style.css, disable dynamic styles */'."\n";		
			
			// google fonts
			if ( ot_get_option( 'font' ) == 'higgs-byekan' ) { $styles .= 'body { font-family: "Higgs-BYekan", Arial, sans-serif; }'."\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-bkoodakbold' ) { $styles .= 'body { font-family: "Higgs-BKoodakBold", serif; }'."\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-casablanca' ) { $styles .= 'body { font-family: "Higgs-Casablanca", Arial, sans-serif; }'."\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-helve23' ) { $styles .= 'body { font-family: "Higgs-Helve23", Arial, sans-serif; }'."\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-kufi' ) { $styles .= 'body { font-family: "Higgs-Kufi", Arial, sans-serif; }'."\n"; }	
			if ( ot_get_option( 'font' ) == 'higgs-kufi-bold' ) { $styles .= 'body { font-family: "Higgs-Kufi-Bold Condensed", Arial, sans-serif; }'."\n"; }			
			if ( ot_get_option( 'font' ) == 'higgs-naskh' )	{ $styles .= 'body { font-family: "Higgs-Naskh", Arial, sans-serif; }'."\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-naskh-bold' ) { $styles .= 'body { font-family: "Higgs-Naskh-Bold", serif; }'."\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-neosans' ) { $styles .= 'body { font-family: "Higgs-NeoSans", sans-serif; }'."\n"; }
			if ( ot_get_option( 'font' ) == 'higgs-sans' ) { $styles .= 'body { font-family: "Higgs-Sans", serif; }'."\n"; }
			
			// container width
			if ( ot_get_option('container-width') != '1380' ) {			
				if ( ot_get_option( 'boxed' ) ) { 
					$styles .= '.boxed #wrapper, .container-inner { max-width: '.ot_get_option('container-width').'px; }'."\n";
				}
				else {
					$styles .= '.container-inner { max-width: '.ot_get_option('container-width').'px; }'."\n";
				}
			}
			// sidebar padding
			if ( ot_get_option('sidebar-padding') != '30' ) {
				$styles .= '.sidebar .widget { padding-left: '.ot_get_option('sidebar-padding').'px; padding-right: '.ot_get_option('sidebar-padding').'px; padding-top: '.ot_get_option('sidebar-padding').'px; }'."\n";
			}
			// primary color
			if ( ot_get_option('color-1') != '#3b8dbd' ) {
				$styles .= '
::selection { background-color: '.ot_get_option('color-1').'; }
::-moz-selection { background-color: '.ot_get_option('color-1').'; }

a,
.themeform label .required,
#flexslider-featured .flex-direction-nav .flex-next:hover,
#flexslider-featured .flex-direction-nav .flex-prev:hover,
.post-hover:hover .post-title a,
.post-title a:hover,
.s1 .post-nav li a:hover i,
.content .post-nav li a:hover i,
.post-related a:hover,
.s1 .widget_rss ul li a,
#footer .widget_rss ul li a,
.s1 .widget_calendar a,
#footer .widget_calendar a,
.s1 .alx-tab .tab-item-category a,
.s1 .alx-posts .post-item-category a,
.s1 .alx-tab li:hover .tab-item-title a,
.s1 .alx-tab li:hover .tab-item-comment a,
.s1 .alx-posts li:hover .post-item-title a,
#footer .alx-tab .tab-item-category a,
#footer .alx-posts .post-item-category a,
#footer .alx-tab li:hover .tab-item-title a,
#footer .alx-tab li:hover .tab-item-comment a,
#footer .alx-posts li:hover .post-item-title a,
.comment-tabs li.active a,
.comment-awaiting-moderation,
.child-menu a:hover,
.child-menu .current_page_item > a,
.wp-pagenavi a { color: '.ot_get_option('color-1').'; }

.themeform input[type="submit"],
.themeform button[type="submit"],
.s1 .sidebar-top,
.s1 .sidebar-toggle,
#flexslider-featured .flex-control-nav li a.flex-active,
.post-tags a:hover,
.s1 .widget_calendar caption,
#footer .widget_calendar caption,
.author-bio .bio-avatar:after,
.commentlist li.bypostauthor > .comment-body:after,
.commentlist li.comment-author-admin > .comment-body:after { background-color: '.ot_get_option('color-1').'; }

.post-format .format-container { border-color: '.ot_get_option('color-1').'; }

.s1 .alx-tabs-nav li.active a,
#footer .alx-tabs-nav li.active a,
.comment-tabs li.active a,
.wp-pagenavi a:hover,
.wp-pagenavi a:active,
.wp-pagenavi span.current { border-bottom-color: '.ot_get_option('color-1').'!important; }				
				'."\n";
			}		
			// secondary color
			if ( ot_get_option('color-2') != '#82b965' ) {
				$styles .= '
.s2 .post-nav li a:hover i,
.s2 .widget_rss ul li a,
.s2 .widget_calendar a,
.s2 .alx-tab .tab-item-category a,
.s2 .alx-posts .post-item-category a,
.s2 .alx-tab li:hover .tab-item-title a,
.s2 .alx-tab li:hover .tab-item-comment a,
.s2 .alx-posts li:hover .post-item-title a { color: '.ot_get_option('color-2').'; }

.s2 .sidebar-top,
.s2 .sidebar-toggle,
.post-comments,
.jp-play-bar,
.jp-volume-bar-value,
.s2 .widget_calendar caption { background-color: '.ot_get_option('color-2').'; }

.s2 .alx-tabs-nav li.active a { border-bottom-color: '.ot_get_option('color-2').'; }
.post-comments span:before { border-right-color: '.ot_get_option('color-2').'; }				
				'."\n";
			}			
			// topbar color
			if ( ot_get_option('color-topbar') != '#26272b' ) {
				$styles .= '
.search-expand,
#nav-topbar.nav-container { background-color: '.ot_get_option('color-topbar').'; }
@media only screen and (min-width: 720px) {
	#nav-topbar .nav ul { background-color: '.ot_get_option('color-topbar').'; }
}			
				'."\n";
			}			
			// header color
			if ( ot_get_option('color-header') != '#33363b' ) {
				$styles .= '
#header { background-color: '.ot_get_option('color-header').'; }
@media only screen and (min-width: 720px) {
	#nav-header .nav ul { background-color: '.ot_get_option('color-header').'; }
}			
				'."\n";
			}
			// header menu color
			if ( ot_get_option('color-header-menu') != '' ) {
				$styles .= '
#nav-header.nav-container { background-color: '.ot_get_option('color-header-menu').'; }
@media only screen and (min-width: 720px) {
	#nav-header .nav ul { background-color: '.ot_get_option('color-header-menu').'; }
}			
				'."\n";
			}			
			// footer color
			if ( ot_get_option('color-footer') != '#33363b' ) {
				$styles .= '#footer-bottom { background-color: '.ot_get_option('color-footer').'; }'."\n";
			}			
			// header logo max-height
			if ( ot_get_option('logo-max-height') != '60' ) {
				$styles .= '.site-title a img { max-height: '.ot_get_option('logo-max-height').'px; }'."\n";
			}
			// image border radius
			if ( ot_get_option('image-border-radius') != '0' ) {
				$styles .= 'img { -webkit-border-radius: '.ot_get_option('image-border-radius').'px; border-radius: '.ot_get_option('image-border-radius').'px; }'."\n";
			}
			// body background
			if ( ot_get_option('body-background') != '' ) {
				
				$body_background = ot_get_option('body-background');
				$body_color = $body_background['background-color'];
				$body_image = $body_background['background-image'];
				$body_position = $body_background['background-position'];
				$body_attachment = $body_background['background-attachment'];
				$body_repeat = $body_background['background-repeat'];
				$body_size = $body_background['background-size'];
				
				if ( $body_image && $body_size == "" ) {
					$styles .= 'body { background: '.$body_color.' url('.$body_image.') '.$body_attachment.' '.$body_position.' '.$body_repeat.'; }'."\n";
				} elseif ( $body_image && $body_size != "" ) {
					$styles .= 'body { background: '.$body_color.' url('.$body_image.') '.$body_attachment.' '.$body_position.' '.$body_repeat.'; background-size: '.$body_size.'; }'."\n";
				} elseif ( $body_background['background-color'] ) {
					$styles .= 'body { background-color: '.$body_color.'; }'."\n";
				} else {
					$styles .= '';
				}
			}
			
			$styles .= '</style>'."\n";
			// end output
			
			echo $styles;		
		}
	}
	
}
add_action( 'wp_head', 'alx_dynamic_css', 100 );
