<?php

/*  Initialize the options before anything else. 
/* ------------------------------------ */
add_action( 'admin_init', 'custom_theme_options', 1 );


/*  Build the custom settings & update OptionTree.
/* ------------------------------------ */
function custom_theme_options() {
	
	// Get a copy of the saved settings array.
	$saved_settings = get_option( 'option_tree_settings', array() );

	// Custom settings array that will eventually be passed to the OptionTree Settings API Class.
	$custom_settings = array(

/*  Help pages
/* ------------------------------------ */	
	'contextual_help' => array(
      'content'       => array( 
        array(
          'id'        => 'general_help',
          'title'     => __('Documentation','hueman'),
          'content'   => '
			<h1>Hueman</h1>
			<p>Thanks for using this theme! Enjoy.</p>
			<ul>
				<li>Read the theme documentation <a target="_blank" href="'.get_template_directory_uri().'/functions/documentation/documentation.html">here</a></li>
				<li>Download the sample child theme <a href="https://github.com/AlxMedia/hueman-child/archive/master.zip">here</a></li>
				<li>Download or contribute translations <a target="_blank" href="https://github.com/AlxMedia/hueman-languages">here</a></li>
				<li>Feel free to rate/review the theme <a target="_blank" href="http://wordpress.org/support/view/theme-reviews/hueman">here</a></li>
				<li>If you have theme questions, go <a target="_blank" href="http://wordpress.org/support/theme/hueman">here</a></li>
				<li>Hueman is on <a target="_blank" href="https://github.com/AlxMedia/hueman">GitHub</a></li>
			</ul>
			<hr />
			<p>You can support the theme author by donating <a target="_blank" href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=K54RW72RZM2HN">here</a> – any amount is always appreciated.</p>
		'
        )
      )
    ),
	
/*  Admin panel sections
/* ------------------------------------ */	
	'sections'        => array(
		array(
			'id'		=> 'general',
			'title'		=>__( 'General','hueman')
		),
		array(
			'id'		=> 'blog',
			'title'		=>__( 'Blog','hueman')
		),
		array(
			'id'		=> 'header',
			'title'		=>__( 'Header','hueman')
		),
		array(
			'id'		=> 'footer',
			'title'		=>__( 'Footer','hueman')
		),
		array(
			'id'		=> 'layout',
			'title'		=>__( 'Layout','hueman')
		),
		array(
			'id'		=> 'sidebars',
			'title'		=>__( 'Sidebars','hueman')
		),
		array(
			'id'		=> 'social-links',
			'title'		=>__( 'Social Links','hueman')
		),
		array(
			'id'		=> 'styling',
			'title'		=>__( 'Styling','hueman')
		),
	),
	
/*  Theme options
/* ------------------------------------ */
	'settings'        => array(
		
		// General: Custom CSS
		array(
			'id'		=> 'custom',
			'label'		=> __('Custom Stylesheet','hueman'),
			'desc'		=> __('Load custom stylesheet [ <strong>custom.css</strong> ]<br /><i>Note: You must backup this file before a theme update. Consider using a <a target="_blank" href="http://codex.wordpress.org/Child_Themes">child theme</a> instead. A sample child theme is available in the help dropdown.</i>','hueman'),
			'std'		=> 'off',
			'type'		=> 'on-off',
			'section'	=> 'general'
		),
		// General: Responsive Layout
		array(
			'id'		=> 'responsive',
			'label'		=> __('Responsive Layout','hueman'),
			'desc'		=> __('Mobile and tablet optimizations [ <strong>responsive.css</strong> ]','hueman'),
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'general'
		),
		// General: Mobile Sidebar
		array(
			'id'		=> 'mobile-sidebar-hide',
			'label'		=> __('Mobile Sidebar Content','hueman'),
			'desc'		=> __('Hide sidebar content on low-resolution mobile devices (320px)','hueman'),
			'type'		=> 'radio',
			'std'		=> '1',
			'section'	=> 'general',
			'choices'	=> array(
				array( 
					'value' => '1',
					'label' =>__( 'Show sidebars','hueman')
				),
				array( 
					'value' => 's1',
					'label' =>__( 'Hide primary sidebar','hueman')
				),
				array( 
					'value' => 's2',
					'label' =>__( 'Hide secondary sidebar','hueman')
				),
				array( 
					'value' => 's1-s2',
					'label' =>__( 'Hide both sidebars','hueman')
				)
			)
		),
		// General: Favicon
		array(
			'id'		=> 'favicon',
			'label'		=> __('Favicon','hueman'),
			'desc'		=> __('Upload a 16x16px Png/Gif image that will be your favicon','hueman'),
			'type'		=> 'upload',
			'section'	=> 'general'
		),
		// General: RSS Feed
		array(
			'id'		=> 'rss-feed',
			'label'		=> __('FeedBurner URL','hueman'),
			'desc'		=> __('Enter your full FeedBurner URL (or any other preferred feed URL) if you wish to use FeedBurner over the standard WordPress feed e.g. http://feeds.feedburner.com/yoururlhere ','hueman'),
			'type'		=> 'text',
			'section'	=> 'general'
		),
		// General: Tracking Code
		array(
			'id'		=> 'tracking-code',
			'label'		=> __('Tracking Code','hueman'),
			'desc'		=> __('Paste your Google Analytics (or other) tracking code here. It will be inserted before the closing body tag of your theme.','hueman'),
			'type'		=> 'textarea-simple',
			'section'	=> 'general',
			'rows'		=> '3'
		),
		// General: Comments
		array(
			'id'		=> 'page-comments',
			'label'		=> __('Page Comments','hueman'),
			'desc'		=> __('Comments on pages','hueman'),
			'std'		=> 'off',
			'type'		=> 'on-off',
			'section'	=> 'general'
		),
		// Blog: Heading
		array(
			'id'		=> 'blog-heading',
			'label'		=> __('Heading','hueman'),
			'desc'		=> __('Your blog heading','hueman'),
			'type'		=> 'text',
			'section'	=> 'blog'
		),
		// Blog: Subheading
		array(
			'id'		=> 'blog-subheading',
			'label'		=> __('Subheading','hueman'),
			'desc'		=> __('Your blog subheading','hueman'),
			'type'		=> 'text',
			'section'	=> 'blog'
		),
		// Blog: Excerpt Length
		array(
			'id'			=> 'excerpt-length',
			'label'			=> __('Excerpt Length','hueman'),
			'desc'			=>__( 'Max number of words','hueman'),
			'std'			=> '34',
			'type'			=> 'numeric-slider',
			'section'		=> 'blog',
			'min_max_step'	=> '0,100,1'
		),
		// Blog: Featured Posts
		array(
			'id'		=> 'featured-posts-include',
			'label'		=> __('Featured Posts','hueman'),
			'desc'		=> __('To show featured posts in the slider AND the content below<br /><i>Usually not recommended</i>','hueman'),
			'type'		=> 'checkbox',
			'section'	=> 'blog',
			'choices'	=> array(
				array( 
					'value' => '1',
					'label' =>__( 'Include featured posts in content area','hueman')
				)
			)
		),
		// Blog: Featured Category
		array(
			'id'		=> 'featured-category',
			'label'		=> __('Featured Category','hueman'),
			'desc'		=> __('By not selecting a category, it will show your latest post(s) from all categories','hueman'),
			'type'		=> 'category-select',
			'section'	=> 'blog'
		),
		// Blog: Featured Category Count
		array(
			'id'			=> 'featured-posts-count',
			'label'			=> __('Featured Post Count','hueman'),
			'desc'			=>__( 'Max number of featured posts to display. <br /><i>Set to 1 and it will show it without any slider script</i><br /><i>Set it to 0 to disable</i>','hueman'),
			'std'			=> '1',
			'type'			=> 'numeric-slider',
			'section'		=> 'blog',
			'min_max_step'	=> '0,10,1'
		),
		// Blog: Thumbnail Placeholder
		array(
			'id'		=> 'placeholder',
			'label'		=> __('Thumbnail Placeholder','hueman'),
			'desc'		=> __('Show featured image placeholders if no featured image is set','hueman'),
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'blog'
		),
		// Blog: Comment Count
		array(
			'id'		=> 'comment-count',
			'label'		=> __('Thumbnail Comment Count','hueman'),
			'desc'		=> __('Comment count on thumbnails','hueman'),
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'blog'
		),
		// Blog: Single - Sharrre
		array(
			'id'		=> 'sharrre',
			'label'		=> __('Single &mdash; Share Bar','hueman'),
			'desc'		=> __('Social sharing buttons for each article','hueman'),
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'blog'
		),
		// Blog: Single - Sharrre Sticky
		array(
			'id'		=> 'sharrre-scrollable',
			'label'		=> __('Single &mdash; Scrollable Share Bar','hueman'),
			'desc'		=> __('Make social links stick to browser window when scrolling down','hueman'),
			'std'		=> 'off',
			'type'		=> 'on-off',
			'section'	=> 'blog'
		),
		// Blog: Twitter Username
		array(
			'id'		=> 'twitter-username',
			'label'		=> __('Twitter Username','hueman'),
			'desc'		=> __('Your @username will be added to share-tweets of your posts (optional)','hueman'),
			'type'		=> 'text',
			'section'	=> 'blog'
		),
		// Blog: Single - Authorbox
		array(
			'id'		=> 'author-bio',
			'label'		=> __('Single &mdash; Author Bio','hueman'),
			'desc'		=> __('Shows post author description, if it exists','hueman'),
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'blog'
		),
		// Blog: Single - Related Posts
		array(
			'id'		=> 'related-posts',
			'label'		=> __('Single &mdash; Related Posts','hueman'),
			'desc'		=> __('Shows randomized related articles below the post','hueman'),
			'std'		=> 'categories',
			'type'		=> 'radio',
			'section'	=> 'blog',
			'choices'	=> array(
				array( 
					'value' => '1',
					'label' =>__( 'Disable','hueman')
				),
				array( 
					'value' => 'categories',
					'label' =>__( 'Related by categories','hueman')
				),
				array( 
					'value' => 'tags',
					'label' =>__( 'Related by tags','hueman')
				)
			)
		),
		// Blog: Single - Post Navigation Location
		array(
			'id'		=> 'post-nav',
			'label'		=> __('Single &mdash; Post Navigation','hueman'),
			'desc'		=> __('Shows links to the next and previous article','hueman'),
			'std'		=> 's1',
			'type'		=> 'radio',
			'section'	=> 'blog',
			'choices'	=> array(
				array( 
					'value' => '1',
					'label' =>__( 'Disable','hueman')
				),
				array( 
					'value' => 's1',
					'label' =>__( 'Sidebar Primary','hueman')
				),
				array( 
					'value' => 's2',
					'label' =>__( 'Sidebar Secondary','hueman')
				),
				array( 
					'value' => 'content',
					'label' =>__( 'Below content','hueman')
				)
			)
		),
		// Header: Custom Logo
		array(
			'id'		=> 'custom-logo',
			'label'		=> __('Custom Logo','hueman'),
			'desc'		=> __('Upload your custom logo image. Set logo max-height in styling options.','hueman'),
			'type'		=> 'upload',
			'section'	=> 'header'
		),
		// Header: Site Description
		array(
			'id'		=> 'site-description',
			'label'		=> __('Site Description','hueman'),
			'desc'		=> __('The description that appears next to your logo','hueman'),
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'header'
		),
		// Header: Header Image
		array(
			'id'		=> 'header-image',
			'label'		=> __('Header Image','hueman'),
			'desc'		=> __('Upload a header image. This will disable header title/logo and description.','hueman'),
			'type'		=> 'upload',
			'section'	=> 'header'
		),
		// Footer: Widget Columns
		array(
			'id'		=> 'footer-widgets',
			'label'		=> __('Footer Widget Columns','hueman'),
			'desc'		=> __('Select columns to enable footer widgets<br /><i>Recommended number: 3</i>','hueman'),
			'std'		=> '0',
			'type'		=> 'radio-image',
			'section'	=> 'footer',
			'class'		=> '',
			'choices'	=> array(
				array(
					'value'		=> '0',
					'label'		=> __('Disable','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/layout-off.png'
				),
				array(
					'value'		=> '1',
					'label'		=> __('1 Column','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/footer-widgets-1.png'
				),
				array(
					'value'		=> '2',
					'label'		=> __('2 Columns','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/footer-widgets-2.png'
				),
				array(
					'value'		=> '3',
					'label'		=> __('3 Columns','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/footer-widgets-3.png'
				),
				array(
					'value'		=> '4',
					'label'		=> __('4 Columns','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/footer-widgets-4.png'
				)
			)
		),
		// Footer: Custom Logo
		array(
			'id'		=> 'footer-logo',
			'label'		=> __('Footer Logo','hueman'),
			'desc'		=> __('Upload your custom logo image','hueman'),
			'type'		=> 'upload',
			'section'	=> 'footer'
		),
		// Footer: Copyright
		array(
			'id'		=> 'copyright',
			'label'		=> __('Footer Copyright','hueman'),
			'desc'		=> __('Replace the footer copyright text','hueman'),
			'type'		=> 'text',
			'section'	=> 'footer'
		),
		// Footer: Credit
		array(
			'id'		=> 'credit',
			'label'		=> __('Footer Credit','hueman'),
			'desc'		=> __('Footer credit text','hueman'),
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'footer'
		),
		// Layout : Global
		array(
			'id'		=> 'layout-global',
			'label'		=> __('Global Layout','hueman'),
			'desc'		=> __('Other layouts will override this option if they are set','hueman'),
			'std'		=> 'col-3cm',
			'type'		=> 'radio-image',
			'section'	=> 'layout',
			'choices'	=> array(
				array(
					'value'		=> 'col-1c',
					'label'		=> __('1 Column','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-1c.png'
				),
				array(
					'value'		=> 'col-2cl',
					'label'		=> __('2 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cl.png'
				),
				array(
					'value'		=> 'col-2cr',
					'label'		=> __('2 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cr.png'
				),
				array(
					'value'		=> 'col-3cm',
					'label'		=> __('3 Column Middle','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cm.png'
				),
				array(
					'value'		=> 'col-3cl',
					'label'		=> __('3 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cl.png'
				),
				array(
					'value'		=> 'col-3cr',
					'label'		=> __('3 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cr.png'
				)
			)
		),
		// Layout : Home
		array(
			'id'		=> 'layout-home',
			'label'		=> __('Home','hueman'),
			'desc'		=> __('[ <strong>is_home</strong> ] Posts homepage layout','hueman'),
			'std'		=> 'inherit',
			'type'		=> 'radio-image',
			'section'	=> 'layout',
			'choices'	=> array(
				array(
					'value'		=> 'inherit',
					'label'		=> __('Inherit Global Layout','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/layout-off.png'
				),
				array(
					'value'		=> 'col-1c',
					'label'		=> __('1 Column','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-1c.png'
				),
				array(
					'value'		=> 'col-2cl',
					'label'		=> __('2 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cl.png'
				),
				array(
					'value'		=> 'col-2cr',
					'label'		=> __('2 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cr.png'
				),
				array(
					'value'		=> 'col-3cm',
					'label'		=> __('3 Column Middle','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cm.png'
				),
				array(
					'value'		=> 'col-3cl',
					'label'		=> __('3 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cl.png'
				),
				array(
					'value'		=> 'col-3cr',
					'label'		=> __('3 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cr.png'
				)
			)
		),
		// Layout : Single
		array(
			'id'		=> 'layout-single',
			'label'		=> __('Single','hueman'),
			'desc'		=> __('[ <strong>is_single</strong> ] Single post layout - If a post has a set layout, it will override this.','hueman'),
			'std'		=> 'inherit',
			'type'		=> 'radio-image',
			'section'	=> 'layout',
			'choices'	=> array(
				array(
					'value'		=> 'inherit',
					'label'		=> __('Inherit Global Layout','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/layout-off.png'
				),
				array(
					'value'		=> 'col-1c',
					'label'		=> __('1 Column','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-1c.png'
				),
				array(
					'value'		=> 'col-2cl',
					'label'		=> __('2 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cl.png'
				),
				array(
					'value'		=> 'col-2cr',
					'label'		=> __('2 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cr.png'
				),
				array(
					'value'		=> 'col-3cm',
					'label'		=> __('3 Column Middle','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cm.png'
				),
				array(
					'value'		=> 'col-3cl',
					'label'		=> __('3 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cl.png'
				),
				array(
					'value'		=> 'col-3cr',
					'label'		=> __('3 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cr.png'
				)
			)
		),
		// Layout : Archive
		array(
			'id'		=> 'layout-archive',
			'label'		=> __('Archive','hueman'),
			'desc'		=> __('[ <strong>is_archive</strong> ] Category, date, tag and author archive layout','hueman'),
			'std'		=> 'inherit',
			'type'		=> 'radio-image',
			'section'	=> 'layout',
			'choices'	=> array(
				array(
					'value'		=> 'inherit',
					'label'		=> __('Inherit Global Layout','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/layout-off.png'
				),
				array(
					'value'		=> 'col-1c',
					'label'		=> __('1 Column','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-1c.png'
				),
				array(
					'value'		=> 'col-2cl',
					'label'		=> __('2 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cl.png'
				),
				array(
					'value'		=> 'col-2cr',
					'label'		=> __('2 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cr.png'
				),
				array(
					'value'		=> 'col-3cm',
					'label'		=> __('3 Column Middle','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cm.png'
				),
				array(
					'value'		=> 'col-3cl',
					'label'		=> __('3 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cl.png'
				),
				array(
					'value'		=> 'col-3cr',
					'label'		=> __('3 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cr.png'
				)
			)
		),
		// Layout : Archive - Category
		array(
			'id'		=> 'layout-archive-category',
			'label'		=> __('Archive &mdash; Category','hueman'),
			'desc'		=> __('[ <strong>is_category</strong> ] Category archive layout','hueman'),
			'std'		=> 'inherit',
			'type'		=> 'radio-image',
			'section'	=> 'layout',
			'choices'	=> array(
				array(
					'value'		=> 'inherit',
					'label'		=> __('Inherit Global Layout','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/layout-off.png'
				),
				array(
					'value'		=> 'col-1c',
					'label'		=> __('1 Column','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-1c.png'
				),
				array(
					'value'		=> 'col-2cl',
					'label'		=> __('2 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cl.png'
				),
				array(
					'value'		=> 'col-2cr',
					'label'		=> __('2 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cr.png'
				),
				array(
					'value'		=> 'col-3cm',
					'label'		=> __('3 Column Middle','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cm.png'
				),
				array(
					'value'		=> 'col-3cl',
					'label'		=> __('3 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cl.png'
				),
				array(
					'value'		=> 'col-3cr',
					'label'		=> __('3 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cr.png'
				)
			)
		),
		// Layout : Search
		array(
			'id'		=> 'layout-search',
			'label'		=> __('Search','hueman'),
			'desc'		=> __('[ <strong>is_search</strong> ] Search page layout','hueman'),
			'std'		=> 'inherit',
			'type'		=> 'radio-image',
			'section'	=> 'layout',
			'choices'	=> array(
				array(
					'value'		=> 'inherit',
					'label'		=> __('Inherit Global Layout','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/layout-off.png'
				),
				array(
					'value'		=> 'col-1c',
					'label'		=> __('1 Column','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-1c.png'
				),
				array(
					'value'		=> 'col-2cl',
					'label'		=> __('2 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cl.png'
				),
				array(
					'value'		=> 'col-2cr',
					'label'		=> __('2 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cr.png'
				),
				array(
					'value'		=> 'col-3cm',
					'label'		=> __('3 Column Middle','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cm.png'
				),
				array(
					'value'		=> 'col-3cl',
					'label'		=> __('3 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cl.png'
				),
				array(
					'value'		=> 'col-3cr',
					'label'		=> __('3 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cr.png'
				)
			)
		),
		// Layout : Error 404
		array(
			'id'		=> 'layout-404',
			'label'		=> __('Error 404','hueman'),
			'desc'		=> __('[ <strong>is_404</strong> ] Error 404 page layout','hueman'),
			'std'		=> 'inherit',
			'type'		=> 'radio-image',
			'section'	=> 'layout',
			'choices'	=> array(
				array(
					'value'		=> 'inherit',
					'label'		=> __('Inherit Global Layout','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/layout-off.png'
				),
				array(
					'value'		=> 'col-1c',
					'label'		=> __('1 Column','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-1c.png'
				),
				array(
					'value'		=> 'col-2cl',
					'label'		=> __('2 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cl.png'
				),
				array(
					'value'		=> 'col-2cr',
					'label'		=> __('2 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cr.png'
				),
				array(
					'value'		=> 'col-3cm',
					'label'		=> __('3 Column Middle','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cm.png'
				),
				array(
					'value'		=> 'col-3cl',
					'label'		=> __('3 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cl.png'
				),
				array(
					'value'		=> 'col-3cr',
					'label'		=> __('3 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cr.png'
				)
			)
		),
		// Layout : Default Page
		array(
			'id'		=> 'layout-page',
			'label'		=> __('Default Page','hueman'),
			'desc'		=> __('[ <strong>is_page</strong> ] Default page layout - If a page has a set layout, it will override this.','hueman'),
			'std'		=> 'inherit',
			'type'		=> 'radio-image',
			'section'	=> 'layout',
			'choices'	=> array(
				array(
					'value'		=> 'inherit',
					'label'		=> __('Inherit Global Layout','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/layout-off.png'
				),
				array(
					'value'		=> 'col-1c',
					'label'		=> __('1 Column','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-1c.png'
				),
				array(
					'value'		=> 'col-2cl',
					'label'		=> __('2 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cl.png'
				),
				array(
					'value'		=> 'col-2cr',
					'label'		=> __('2 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-2cr.png'
				),
				array(
					'value'		=> 'col-3cm',
					'label'		=> __('3 Column Middle','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cm.png'
				),
				array(
					'value'		=> 'col-3cl',
					'label'		=> __('3 Column Left','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cl.png'
				),
				array(
					'value'		=> 'col-3cr',
					'label'		=> __('3 Column Right','hueman'),
					'src'		=> get_template_directory_uri() . '/functions/images/col-3cr.png'
				)
			)
		),
		// Sidebars: Create Areas
		array(
			'id'		=> 'sidebar-areas',
			'label'		=> __('Create Sidebars','hueman'),
			'desc'		=> __('You must save changes for the new areas to appear below. <br /><i>Warning: Make sure each area has a unique ID.</i>','hueman'),
			'type'		=> 'list-item',
			'section'	=> 'sidebars',
			'choices'	=> array(),
			'settings'	=> array(
				array(
					'id'		=> 'id',
					'label'		=> __('Sidebar ID','hueman'),
					'desc'		=> __('This ID must be unique, for example "sidebar-about"','hueman'),
					'std'		=> 'sidebar-',
					'type'		=> 'text',
					'choices'	=> array()
				)
			)
		),
		// Sidebar 1 & 2
		array(
			'id'		=> 's1-home',
			'label'		=> __('Home','hueman'),
			'desc'		=> __('[ <strong>is_home</strong> ] Primary','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's2-home',
			'label'		=> __('Home','hueman'),
			'desc'		=> __('[ <strong>is_home</strong> ] Secondary','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's1-single',
			'label'		=> __('Single','hueman'),
			'desc'		=> __('[ <strong>is_single</strong> ] Primary - If a single post has a unique sidebar, it will override this.','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's2-single',
			'label'		=> __('Single','hueman'),
			'desc'		=> __('[ <strong>is_single</strong> ] Secondary - If a single post has a unique sidebar, it will override this.','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's1-archive',
			'label'		=> __('Archive','hueman'),
			'desc'		=> __('[ <strong>is_archive</strong> ] Primary','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's2-archive',
			'label'		=> __('Archive','hueman'),
			'desc'		=> __('[ <strong>is_archive</strong> ] Secondary','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's1-archive-category',
			'label'		=> __('Archive &mdash; Category','hueman'),
			'desc'		=> __('[ <strong>is_category</strong> ] Primary','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's2-archive-category',
			'label'		=> __('Archive &mdash; Category','hueman'),
			'desc'		=> __('[ <strong>is_category</strong> ] Secondary','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's1-search',
			'label'		=> __('Search','hueman'),
			'desc'		=> __('[ <strong>is_search</strong> ] Primary','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's2-search',
			'label'		=> __('Search','hueman'),
			'desc'		=> __('[ <strong>is_search</strong> ] Secondary','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's1-404',
			'label'		=> __('Error 404','hueman'),
			'desc'		=> __('[ <strong>is_404</strong> ] Primary','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's2-404',
			'label'		=> __('Error 404','hueman'),
			'desc'		=> __('[ <strong>is_404</strong> ] Secondary','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's1-page',
			'label'		=> __('Default Page','hueman'),
			'desc'		=> __('[ <strong>is_page</strong> ] Primary - If a page has a unique sidebar, it will override this.','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		array(
			'id'		=> 's2-page',
			'label'		=> __('Default Page','hueman'),
			'desc'		=> __('[ <strong>is_page</strong> ] Secondary - If a page has a unique sidebar, it will override this.','hueman'),
			'type'		=> 'sidebar-select',
			'section'	=> 'sidebars'
		),
		// Social Links : List
		array(
			'id'		=> 'social-links',
			'label'		=> __('Social Links','hueman'),
			'desc'		=> __('Create and organize your social links','hueman'),
			'type'		=> 'list-item',
			'section'	=> 'social-links',
			'choices'	=> array(),
			'settings'	=> array(
				array(
					'id'		=> 'social-icon',
					'label'		=> __('Icon Name','hueman'),
					'desc'		=> __('Font Awesome icon names [<a href="http://fortawesome.github.io/Font-Awesome/icons/" target="_blank"><strong>View all</strong>]</a>  ','hueman'),
					'std'		=> 'fa-',
					'type'		=> 'text',
					'choices'	=> array()
				),
				array(
					'id'		=> 'social-link',
					'label'		=> __('Link','hueman'),
					'desc'		=> __('Enter the full url for your icon button','hueman'),
					'std'		=> 'http://',
					'type'		=> 'text',
					'choices'	=> array()
				),
				array(
					'id'		=> 'social-color',
					'label'		=> __('Icon Color','hueman'),
					'desc'		=> __('Set a unique color for your icon (optional)','hueman'),
					'std'		=> '',
					'type'		=> 'colorpicker',
					'section'	=> 'styling'
				),
				array(
					'id'		=> 'social-target',
					'label'		=> __('Link Options','hueman'),
					'desc'		=> '',
					'std'		=> '',
					'type'		=> 'checkbox',
					'choices'	=> array(
						array( 
							'value' => '_blank',
							'label' =>__( 'Open in new window','hueman')
						)
					)
				)
			)
		),
		// Styling: Enable
		array(
			'id'		=> 'dynamic-styles',
			'label'		=> __('Dynamic Styles','hueman'),
			'desc'		=> __('Turn on to use the styling options below','hueman'),
			'std'		=> 'on',
			'type'		=> 'on-off',
			'section'	=> 'styling'
		),
		// Styling: Boxed Layout
		array(
			'id'		=> 'boxed',
			'label'		=> __('Boxed Layout','hueman'),
			'desc'		=> __('Use a boxed layout','hueman'),
			'std'		=> 'off',
			'type'		=> 'on-off',
			'section'	=> 'styling'
		),
		// Styling: Font
		array(
			'id'		=> 'font',
			'label'		=> __('Font','hueman'),
			'desc'		=> __('Select font for the theme','hueman'),
			'type'		=> 'select',
			'std'		=> '30',
			'section'	=> 'styling',
			'choices'	=> array(
				array( 
					'value' => 'higgs-byekan',
					'label' =>'Higgs BYekan'
				),
				array( 
					'value' => 'higgs-bkoodakbold',
					'label' =>'Higgs BKoodakBold'
				),
				array( 
					'value' => 'higgs-casablanca',
					'label' =>'Higgs Casablanca'
				),
				array( 
					'value' => 'higgs-helve23',
					'label' =>'Higgs Helve'
				),
				array( 
					'value' => 'higgs-kufi',
					'label' =>'Higgs Kufi'
				),
				array( 
					'value' => 'higgs-kufi-bold',
					'label' =>'Higgs Kufi Bold'
				),
				array( 
					'value' => 'higgs-naskh',
					'label' =>'Higgs Naskh'
				),
				array( 
					'value' => 'higgs-naskh-bold',
					'label' =>'Higgs Naskh Bold'
				),
				array( 
					'value' => 'higgs-neosans',
					'label' =>'Higgs NeoSans'
				),
				array( 
					'value' => 'higgs-sans',
					'label' =>'Higgs Sans'
				)
			)
		),
		// Styling: Container Width
		array(
			'id'			=> 'container-width',
			'label'			=> __('Website Max-width','hueman'),
			'desc'			=>__( 'Max-width of the container. If you use 2 sidebars, your container should be at least 1200px.<br /><i>Note: For 720px content (default) use <strong>1380px</strong> for 2 sidebars and <strong>1120px</strong> for 1 sidebar. If you use a combination of both, try something inbetween.</i>','hueman'),
			'std'			=> '1380',
			'type'			=> 'numeric-slider',
			'section'		=> 'styling',
			'min_max_step'	=> '1024,1600,1'
		),
		// Styling: Sidebar Padding
		array(
			'id'		=> 'sidebar-padding',
			'label'		=> __('Sidebar Width','hueman'),
			'type'		=> 'radio',
			'std'		=> '30',
			'section'	=> 'styling',
			'choices'	=> array(
				array( 
					'value' => '30',
					'label' =>__( '280px primary, 200px secondary (30px padding)','hueman')
				),
				array( 
					'value' => '20',
					'label' =>__( '300px primary, 220px secondary (20px padding)','hueman')
				)
			)
		),
		// Styling: Primary Color
		array(
			'id'		=> 'color-1',
			'label'		=> __('Primary Color','hueman'),
			'std'		=> '#3b8dbd',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
			'class'		=> ''
		),
		// Styling: Secondary Color
		array(
			'id'		=> 'color-2',
			'label'		=> __('Secondary Color','hueman'),
			'std'		=> '#82b965',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
			'class'		=> ''
		),
		// Styling: Topbar Background
		array(
			'id'		=> 'color-topbar',
			'label'		=> __('Topbar Background','hueman'),
			'std'		=> '#26272b',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
			'class'		=> ''
		),
		// Styling: Header Background
		array(
			'id'		=> 'color-header',
			'label'		=> __('Header Background','hueman'),
			'std'		=> '#33363b',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
			'class'		=> ''
		),
		// Styling: Header Menu Background
		array(
			'id'		=> 'color-header-menu',
			'label'		=> __('Header Menu Background','hueman'),
			'std'		=> '',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
			'class'		=> ''
		),
		// Styling: Footer Background
		array(
			'id'		=> 'color-footer',
			'label'		=> __('Footer Background','hueman'),
			'std'		=> '#33363b',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
			'class'		=> ''
		),
		// Styling: Header Logo Max-height
		array(
			'id'			=> 'logo-max-height',
			'label'			=> __('Header Logo Image Max-height','hueman'),
			'desc'			=>__( 'Your logo image should have the double height of this to be high resolution','hueman'),
			'std'			=> '60',
			'type'			=> 'numeric-slider',
			'section'		=> 'styling',
			'min_max_step'	=> '40,200,1'
		),
		// Styling: Image Border Radius
		array(
			'id'			=> 'image-border-radius',
			'label'			=> __('Image Border Radius','hueman'),
			'desc'			=>__( 'Give your thumbnails and layout images rounded corners','hueman'),
			'std'			=> '0',
			'type'			=> 'numeric-slider',
			'section'		=> 'styling',
			'min_max_step'	=> '0,15,1'
		),
		// Styling: Body Background
		array(
			'id'		=> 'body-background',
			'label'		=> __('Body Background','hueman'),
			'desc'		=> __('Set background color and/or upload your own background image','hueman'),
			'type'		=> 'background',
			'section'	=> 'styling'
		)
	)
);

/*  Settings are not the same? Update the DB
/* ------------------------------------ */
	if ( $saved_settings !== $custom_settings ) {
		update_option( 'option_tree_settings', $custom_settings ); 
	} 
}
